# TODO:
#
# - support for miniupnpc

#%define		commit_hash	354c0f382b

%define         opensslversion 	1.0.1l

Name:           bitcoin
Version:        0.10.0
Release:        1%{?dist}
Summary:        A peer-to-peer electronic crypto-currency cash system
Group:          Applications/Internet
License:        MIT
URL:            http://bitcoin.org/
#Source0:        bitcoin-v%{version}-g%{commit_hash}.tar.bz2
Source0:	https://github.com/bitcoin/bitcoin/archive/v%{version}.tar.gz
# git clone https://github.com/bitcoin/bitcoin.git && cd bitcoin
# git checkout %%{commit_hash} && (cd ..; tar -zcvf bitcoin-v%{version}-g%{commit_hash}.tar.bz2 bitcoin)

# bitcoin needs to rebuild OpenSSL with ECC support https://bitcointalk.org/index.php?topic=9476.0
Source1:        http://www.openssl.org/source/openssl-%{opensslversion}.tar.gz
Source3:        bitcoin-README.Fedora

BuildRoot:      %{_tmppath}/%{name}-%{version}-%{release}-buildroot

BuildRequires:  db4-devel boost-devel gcc-c++ autoconf automake git
BuildRequires:  desktop-file-utils qt-devel gettext
BuildRequires:	protobuf-compiler protobuf-devel libtool
BuildRequires:	qrencode

%if 0%{?fedora} >= 18
BuildRequires:	libdb4-cxx-devel
%endif

%if 0%{?fedora} >= 20
BuildRequires:	boost-system
%endif

#BuildRequires: miniupnpc-devel

BuildRequires:  mktemp, krb5-devel, perl, sed, zlib-devel, diffutils
BuildRequires:  util-linux

Requires:       desktop-file-utils

%package devel
Summary:  Header files and libraries needed for bitcoin development
Group:    Development/Libraries
Provides: bitcoin-devel = %{version}-%{release}
Provides: bitcoin-libs  = %{version}-%{release}
Requires: bitcoin       = %{version}-%{release}

%description devel
Header files and libraries for bitcoin development

%description
Bitcoin is a free open source peer-to-peer electronic cash system that is
completely decentralized, without the need for a central server or trusted
parties. Users hold the crypto keys to their own money and transact directly
with each other, with the help of a P2P network to check for double-spending.

See the documentation at the bitcoin wiki:
  https://en.bitcoin.it/wiki/Main_Page
for help and more information.

This is the standard-client bitcoin-core.

%prep
%setup -q -n bitcoin-%{version}

# use miniupnpc
#USE_UPNP=1

### building openssl as a bitcoin prep:
## (see README.Fedora for explanation)

tar zxf %{SOURCE1}
#export CFLAGS="-fPIC"
pushd openssl-%{opensslversion}
sed -i "s|^CC= gcc|CC= gcc -fPIC|g" Makefile
./config --prefix=/usr \
        --openssldir=%{_sysconfdir}/pki/tls \
        no-shared \
        -fPIC
make depend
make all
mkdir ./lib
for lib in *.a ; do
    ln -s ../$lib ./lib
done
popd # exiting openssl dir


%build
# bitcoind build:
#export CFLAGS="-fPIC"
#export CPPFLAGS="-fPIC"
export CXXFLAGS="-fPIC"

export SSL_LIBS="-L${RPM_BUILD_DIR}/bitcoin-%{version}/openssl-%{opensslversion}/ -lssl"
export SSL_CFLAGS="-I${RPM_BUILD_DIR}/bitcoin-%{version}/openssl-%{opensslversion}/include"
export CRYPTO_LIBS="-L${RPM_BUILD_DIR}/bitcoin-%{version}/openssl-%{opensslversion}/ -lcrypto -ldl"
export CRYPTO_CFLAGS="-I${RPM_BUILD_DIR}/bitcoin-%{version}/openssl-%{opensslversion}/crypto"

#export CFLAGS="-I${RPM_BUILD_DIR}/bitcoin-%{version}/openssl-%{opensslversion}/include"
export CXXFLAGS="-I${RPM_BUILD_DIR}/bitcoin-%{version}/openssl-%{opensslversion}/include -fPIC"
#export CPPFLAGS="-I${RPM_BUILD_DIR}/bitcoin-%{version}/openssl-%{opensslversion}/include"

./autogen.sh

echo $SSL_CFLAGS
echo $CFLAGS

%configure  --disable-tests
#--disable-ipv6

make %{?_smp_mflags} \
%if 0%{?fedora} <= 19
    BOOST_LIB_SUFFIX=-mt	\
%endif
    USE_UPNP=- #disables UPNP

%install
%makeinstall


%{__install} -m 644 -D -p src/qt/res/src/bitcoin.svg %{buildroot}%{_datadir}/icons/hicolor/scalable/apps/bitcoin.svg

sed -i "s|bitcoin128|bitcoin|g" contrib/debian/bitcoin-qt.desktop
desktop-file-install contrib/debian/bitcoin-qt.desktop \
        --add-category=Network \
        --dir %{buildroot}%{_datadir}/applications 

%{__install} -pD -m 644 contrib/debian/manpages/bitcoind.1 %{buildroot}/%{_mandir}/man1/bitcoind.1
%{__install} -pD -m 644 contrib/debian/manpages/bitcoin-qt.1 %{buildroot}/%{_mandir}/man1/bitcoin-qt.1
%{__install} -pD -m 644 contrib/debian/manpages/bitcoin.conf.5 %{buildroot}/%{_mandir}/man5/bitcoin.conf.5
cp %{SOURCE3} README.Fedora

rm -f %{buildroot}%{_libdir}/libbitcoinconsensus.{la,a}

%clean
rm -rf %{buildroot}

%post
touch --no-create %{_datadir}/icons/hicolor &>/dev/null || :
update-desktop-database &> /dev/null || :

%postun
if [ $1 -eq 0 ] ; then
    touch --no-create %{_datadir}/icons/hicolor &>/dev/null
    gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :
fi
update-desktop-database &> /dev/null || :

%posttrans
gtk-update-icon-cache %{_datadir}/icons/hicolor &>/dev/null || :

%post devel -p /sbin/ldconfig

%postun devel -p /sbin/ldconfig

%files
%defattr(-,root,root,0755)
%doc COPYING README.md README.Fedora contrib/debian/examples/
%{_bindir}/*
%{_mandir}/man5/*
%{_mandir}/man1/*
%{_datadir}/applications/%{name}-qt.desktop
%{_datadir}/icons/hicolor/scalable/apps/%{name}.svg

%files devel
%defattr(-,root,root,-)

%{_libdir}/lib*.so
%{_libdir}/lib*.so.*
%{_includedir}/bitcoinconsensus.h

%changelog
* Fri Feb 13 2015 josef radinger <cheese@nosuchhost.net> - 0.10.0-1
- bump version
- bump openssl
- add BuildRequires on libtool
- add BuildRequires on qrencode
- split devel-package and library

* Sun Oct 26 2014 josef radinger <cheese@nosuchhost.net> - 0.9.3-1
- bump version of bitcoin
- new openssl

* Wed Jul 02 2014 josef radinger <cheese@nosuchhost.net> - 0.9.2.1-2
- and fix ssl :)
- we use our own version again

* Sat Jun 21 2014 josef radinger <cheese@nosuchhost.net> - 0.9.2.1-1
- fedora supports ec, we no longer ship our own openssl
- remove --enable-cli, --enable-daemon, --enable-gui from configure-cmdline
- remove README.fedora
- bump version

* Sat Jun 14 2014 josef radinger <cheese@nosuchhost.net> - 0.9.2-1
- bump version
- cleanup specfile

* Thu Apr 10 2014 josef radinger <cheese@nosuchhost.net> - 0.9.1-2
- new openssl

* Thu Apr 10 2014 josef radinger <cheese@nosuchhost.net> - 0.9.1-1
- bump version

* Tue Apr 08 2014 josef radinger <cheese@nosuchhost.net> - 0.9.0-3
- update openssl

* Sat Mar 29 2014 josef radinger <cheese@nosuchhost.net> - 0.9.0-2
- further cleanup spec-file
- update openssl to 1.0.1f
- enable ipv6

* Sat Mar 22 2014 josef radinger <cheese@nosuchhost.net> - 0.9.0-1
- bump version
- new buildsystem
- protobuf-devel
- clean spec-file

* Sat Jan 18 2014 josef radinger <cheese@nosuchhost.net> - 0.8.6-3
- disable -mt for fedora20 onwards

* Tue Dec 17 2013 josef radinger <cheese@nosuchhost.net> - 0.8.6-2
- fix icon

* Sat Dec 14 2013 josef radinger <cheese@nosuchhost.net> - 0.8.6-1
- bump version

* Fri Sep 27 2013 josef radinger <cheese@nosuchhost.net> - 0.8.5-1
- bump version

* Thu Sep 05 2013 josef radinger <cheese@nosuchhost.net> - 0.8.4-1
- bump version
- add BuildRequires protobuf-compiler

* Sat Jul 06 2013 josef radinger <cheese@nosuchhost.net> - 0.8.3-1
- bump version

* Sun Jun 2 2013 josef radinger <cheese@nosuchhost.net> - 0.8.2-1
- bump version
- move bitcoind from libexec to bin

* Fri Mar 22 2013 josef radinger <cheese@nosuchhost.net> - 0.8.1-1
- bump version

* Sun Feb 24 2013 josef radinger <cheese@nosuchhost.net> - 0.8.0-1
- bump version
- bump version of openssl to 1.0.1e

* Sun Jan 27 2013 josef radinger <cheese@nosuchhost.net> - 0.7.2-2
- rebuild

* Sun Dec 30 2012 josef radinger <cheese@nosuchhost.net> - 0.7.2-1
- bump version

* Sun Oct 21 2012 josef radinger <cheese@nosuchhost.net> - 0.7.1-1
- bump version
- some cleanup of specfile

* Tue Sep 18 2012 josef radinger <cheese@nosuchhost.net> - 0.7.0-2
- conditional fc18-build

* Tue Sep 18 2012 josef radinger <cheese@nosuchhost.net> - 0.7.0-1
- bump version

* Sun Jul 01 2012 josef radinger <cheese@nosuchhost.net> - 0.6.3-2
- modify buildrequires for openssl

* Sat Jun 30 2012 josef radinger <cheese@nosuchhost.net> - 0.6.3-1
- bump version openssl
- bump version bitcoin

* Thu May 17 2012 josef radinger <cheese@nosuchhost.net> - 0.6.2.2-1
- bump version
- mangle spec-file
- download sources and package them, as the "standard" 
  download leads to unversioned builds

* Mon May 07 2012 josef radinger <cheese@nosuchhost.net> - 0.6.1-3
- try to fix openssl-paths

* Mon May 07 2012 josef radinger <cheese@nosuchhost.net> - 0.6.1-2
- full release

* Thu May 03 2012 josef radinger <cheese@nosuchhost.net> - 0.6.1rc2-1
- bump version for bitcoin

* Thu May 03 2012 josef radinger <cheese@nosuchhost.net> - 0.6.0-3
- bump openssl to 1.0.1b

* Thu May 03 2012 josef radinger <cheese@nosuchhost.net> - 0.6.0-2
- recompile, no problems in mock

* Wed Apr 4 2012 <ismael@olea.org> - 0.6.0-1
- updated to 0.6.0*
- deprecated makefile.fedora
- deprecated packager bitcoin-qt.pro
- upgraded to openssl-1.0.0g

* Wed Dec 7 2011 <ismael@olea.org> - 0.5.0-1
- first release

